Filsystem/FilesystemInterface
=============================

This package provides interfaces for classes that act as facades for other more
obscure filesystem, such as the `noccylabs/atk` bridging the Android filesystem,
or `noccylabs/ssh2` that provides a `FilesystemInterface` compatible Sftp subsystem.


## Installing

Install as a dependency using composer

        $ composer require noccylabs/filesysteminterface:0.1.*


Or directly in your composer.json:

        "require": {
            "noccylabs/filesysteminterface": "0.1.*",
            ..


## The interface

This is the interface as of 0.1.0:

        interface NoccyLabs\Filesystem\FilesystemInterface
        {
            public function send($local, $remote, $create_mode=0644);
            public function receive($remote, $local);
            public function chmod($remote, $mode);
            public function mkdir($remote, $mode=0777, $recursive=false);
            public function readlink($remote);
            public function realpath($remote);
            public function rename($from, $to);
            public function stat($remote);
            public function symlink($target, $link);
            public function unlink($remote);
        }


### Using

Most of the methods should be obvious, but some of them may require additional
explanations. 

 * `send` and `receive` transfers files to and from the filesystem implemented.
   Always consider the implemented filesystem remote, even if you know it is
   local. This makes it easier to make your code function over SSH and more.
 * `send`, `chmod` and `mkdir` permissions are as per the inner workings of
   Linux octal, meaning that *777* and *0777* is not the same thing. Remember
   the initial *0* when specifying your modes.
 * `unlink` is used to remove files, directories or symbolic links.
